Welcome to RISC-V Model's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tools
   dev

This is a Python RISC-V model, that can serve many purposes:

* To learn RISC-V Assembly
* As a reference model for verification
* As a source of random instruction streams and programs

Beside the usage as library there are multiple command line tools and utilities.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
